@@ -1,5 +1,6 @@
 #!/usr/bin/env php
 <?php
+
 /*
  * SPDX-License-Identifier: AGPL-3.0-only
  * SPDX-FileCopyrightText: Copyright 2007-2016 Zarafa Deutschland GmbH
@@ -21,7 +22,7 @@ setlocale(LC_ALL, "");
  * MAIN
  */
 declare(ticks=1);
-define('BASE_PATH_CLI', dirname(__FILE__) . "/");
+define('BASE_PATH_CLI', __DIR__ . "/");
 set_include_path(get_include_path() . PATH_SEPARATOR . BASE_PATH_CLI);
 
 if (!defined('GSYNC_CONFIG')) {
@@ -50,7 +51,7 @@ try {
 	}
 
 	if ($zpt->IsAvailable()) {
-		pcntl_signal(SIGINT, [$zpt, "SignalHandler"]);
+		pcntl_signal(SIGINT, $zpt->SignalHandler(...));
 		$zpt->run();
 		$zpt->scrClear();
 		system("stty sane");
@@ -60,7 +61,7 @@ try {
 	}
 }
 catch (GSyncException $zpe) {
-	fwrite(STDERR, get_class($zpe) . ": " . $zpe->getMessage() . "\n");
+	fwrite(STDERR, $zpe::class . ": " . $zpe->getMessage() . "\n");
 
 	exit(1);
 }
@@ -105,6 +106,22 @@ class GSyncTop {
 	private $activeUsers = [];
 	private $activeDevices = [];
 
+	private const LINE_DEFAULTS = [
+		'pid' => 0,
+		'ip' => '',
+		'user' => '',
+		'command' => '',
+		'time' => 0,
+		'devagent' => '',
+		'devid' => '',
+		'addinfo' => '',
+		'asversion' => '',
+		'start' => 0,
+		'update' => 0,
+		'ended' => 0,
+		'push' => false,
+	];
+
 	/**
 	 * Constructor.
 	 */
@@ -227,12 +244,26 @@ class GSyncTop {
 						continue;
 					}
 
-					$line['command'] = Utils::GetCommandFromCode($line['command']);
+					$line = $this->normalizeLine($line);
+					if ($line['pid'] === 0) {
+						continue;
+					}
 
-					if ($line["ended"] == 0) {
+					if (is_numeric($line['command'])) {
+						$command = Utils::GetCommandFromCode((int) $line['command']);
+						$line['command'] = ($command !== false) ? $command : 'Unknown';
+					}
+					elseif ($line['command'] === '') {
+						$line['command'] = 'Unknown';
+					}
+					else {
+						$line['command'] = (string) $line['command'];
+					}
+
+					if ($line["ended"] === 0) {
 						$this->activeDevices[$devid] = 1;
 						$this->activeUsers[$user] = 1;
-						$this->activeConn[$pid] = 1;
+						$this->activeConn[$line['pid']] = 1;
 						$this->activeHosts[$line['ip']] = 1;
 
 						$line["time"] = $this->currenttime - $line['start'];
@@ -247,8 +278,8 @@ class GSyncTop {
 
 						if ($this->filter !== false) {
 							$f = $this->filter;
-							if (!($line["pid"] == $f || $line["ip"] == $f || strtolower($line['command']) == strtolower($f) || preg_match("/.*?{$f}.*?/i", $line['user']) ||
-								preg_match("/.*?{$f}.*?/i", $line['devagent']) || preg_match("/.*?{$f}.*?/i", $line['devid']) || preg_match("/.*?{$f}.*?/i", $line['addinfo']))) {
+							if (!($line["pid"] == $f || $line["ip"] == $f || strtolower((string) $line['command']) == strtolower($f) || preg_match("/.*?{$f}.*?/i", (string) $line['user']) ||
+								preg_match("/.*?{$f}.*?/i", (string) $line['devagent']) || preg_match("/.*?{$f}.*?/i", (string) $line['devid']) || preg_match("/.*?{$f}.*?/i", (string) $line['addinfo']))) {
 								continue;
 							}
 						}
@@ -276,11 +307,11 @@ class GSyncTop {
 								!(
 									$line['pid'] == $f ||
 									$line['ip'] == $f ||
-									strtolower($line['command']) == strtolower($f) ||
-									preg_match("/.*?{$f}.*?/i", $line['user']) ||
-									preg_match("/.*?{$f}.*?/i", $line['devagent']) ||
-									preg_match("/.*?{$f}.*?/i", $line['devid']) ||
-									preg_match("/.*?{$f}.*?/i", $line['addinfo'])
+									strtolower((string) $line['command']) == strtolower($f) ||
+									preg_match("/.*?{$f}.*?/i", (string) $line['user']) ||
+									preg_match("/.*?{$f}.*?/i", (string) $line['devagent']) ||
+									preg_match("/.*?{$f}.*?/i", (string) $line['devid']) ||
+									preg_match("/.*?{$f}.*?/i", (string) $line['addinfo'])
 								)) {
 								continue;
 							}
@@ -300,6 +331,38 @@ class GSyncTop {
 		krsort($this->linesTerm);
 	}
 
+	private function normalizeLine(array $line): array {
+		$normalized = array_replace(self::LINE_DEFAULTS, $line);
+
+		$normalized['pid'] = (int) $normalized['pid'];
+		$normalized['update'] = (int) $normalized['update'];
+		$normalized['start'] = (int) $normalized['start'];
+		$normalized['ended'] = (int) $normalized['ended'];
+		$normalized['time'] = (int) ($normalized['time'] ?? 0);
+
+		if (!is_bool($normalized['push'])) {
+			if (is_scalar($normalized['push'])) {
+				$normalized['push'] = filter_var($normalized['push'], FILTER_VALIDATE_BOOL, FILTER_NULL_ON_FAILURE) ?? false;
+			}
+			else {
+				$normalized['push'] = false;
+			}
+		}
+
+		foreach (['ip', 'user', 'devagent', 'devid', 'addinfo', 'asversion'] as $key) {
+			$normalized[$key] = (string) $normalized[$key];
+		}
+
+		if (is_string($normalized['command']) || is_numeric($normalized['command'])) {
+			$normalized['command'] = (string) $normalized['command'];
+		}
+		else {
+			$normalized['command'] = '';
+		}
+
+		return $normalized;
+	}
+
 	/**
 	 * Prints data to the terminal.
 	 */
@@ -498,7 +561,7 @@ class GSyncTop {
 	 * Waits for a keystroke and processes the requested command.
 	 */
 	private function readLineProcess() {
-		$ans = explode("^^", `bash -c "read -n 1 -t 1 ANS ; echo \\\$?^^\\\$ANS;"`);
+		$ans = explode("^^", (string) `bash -c "read -n 1 -t 1 ANS ; echo \\\$?^^\\\$ANS;"`);
 
 		if ($ans[0] < 128) {
 			if (isset($ans[1]) && bin2hex(trim($ans[1])) == "7f") {
@@ -506,7 +569,7 @@ class GSyncTop {
 			}
 
 			if (isset($ans[1]) && $ans[1] != "") {
-				$this->action .= trim(preg_replace("/[^A-Za-z0-9:]/", "", $ans[1]));
+				$this->action .= trim((string) preg_replace("/[^A-Za-z0-9:]/", "", $ans[1]));
 			}
 
 			if (bin2hex($ans[0]) == "30" && bin2hex($ans[1]) == "0a") {
