@@ -1,8 +1,9 @@
 <?php
+
 /*
  * SPDX-License-Identifier: AGPL-3.0-only
  * SPDX-FileCopyrightText: Copyright 2007-2016 Zarafa Deutschland GmbH
- * SPDX-FileCopyrightText: Copyright 2020-2024 grommunio GmbH
+ * SPDX-FileCopyrightText: Copyright 2020-2025 grommunio GmbH
  *
  * Core functionalities
  */
@@ -150,6 +151,7 @@ class GSync {
 	private static $stateMachine;
 	private static $deviceManager;
 	private static $provisioningManager;
+	private static $connectiontracking;
 	private static $topCollector;
 	private static $backend;
 	private static $addSyncFolders;
@@ -174,7 +176,7 @@ class GSync {
 			throw new FatalMisconfigurationException("The BASE_PATH is not configured. Check if the config.php file is in place.");
 		}
 
-		if (substr(BASE_PATH, -1, 1) != "/") {
+		if (!str_ends_with(BASE_PATH, "/")) {
 			throw new FatalMisconfigurationException("The BASE_PATH should terminate with a '/'");
 		}
 
@@ -193,7 +195,7 @@ class GSync {
 			define('LOGBACKEND', 'filelog');
 		}
 
-		if (strtolower(LOGBACKEND) == 'syslog') {
+		if (strtolower((string) LOGBACKEND) == 'syslog') {
 			define('LOGBACKEND_CLASS', 'Syslog');
 			if (!defined('LOG_SYSLOG_FACILITY')) {
 				define('LOG_SYSLOG_FACILITY', LOG_LOCAL0);
@@ -219,13 +221,13 @@ class GSync {
 				throw new FatalMisconfigurationException("LOG_SYSLOG_HOST is defined but the LOG_SYSLOG_PORT does not seem to be valid.");
 			}
 		}
-		elseif (strtolower(LOGBACKEND) == 'filelog') {
+		elseif (strtolower((string) LOGBACKEND) == 'filelog') {
 			define('LOGBACKEND_CLASS', 'FileLog');
 			if (!defined('LOGFILEDIR')) {
 				throw new FatalMisconfigurationException("The LOGFILEDIR is not configured. Check if the config.php file is in place.");
 			}
 
-			if (substr(LOGFILEDIR, -1, 1) != "/") {
+			if (!str_ends_with(LOGFILEDIR, "/")) {
 				throw new FatalMisconfigurationException("The LOGFILEDIR should terminate with a '/'");
 			}
 
@@ -363,6 +365,8 @@ class GSync {
 		// get the statemachine, which will also try to load the backend.. This could throw errors
 		self::GetStateMachine();
 
+		self::$connectiontracking = new ConnectionTracking();
+
 		return true;
 	}
 
@@ -385,7 +389,7 @@ class GSync {
 					self::GetTopCollector()->AnnounceInformation("Run migration script!", true);
 				}
 
-				throw new ServiceUnavailableException(sprintf("The state version available to the %s is not the latest version - please run the state upgrade script. See release notes for more information.", get_class(GSync::$stateMachine)));
+				throw new ServiceUnavailableException(sprintf("The state version available to the %s is not the latest version - please run the state upgrade script. See release notes for more information.", GSync::$stateMachine::class));
 			}
 		}
 
@@ -458,6 +462,15 @@ class GSync {
 		return self::$provisioningManager;
 	}
 
+	/**
+	 * Tracks the current connection for the device/user.
+	 */
+	public static function TrackConnection() {
+		if (isset(self::$connectiontracking)) {
+			self::$connectiontracking->TrackConnection();
+		}
+	}
+
 	/**
 	 * Returns the DeviceManager object.
 	 *
@@ -501,7 +514,7 @@ class GSync {
 		}
 
 		$backendname = strtolower($backendname);
-		if (substr($backendname, 0, 7) !== 'backend') {
+		if (!str_starts_with($backendname, 'backend')) {
 			throw new FatalNotImplementedException(sprintf("Backend '%s' is not allowed", $backendname));
 		}
 
@@ -821,7 +834,7 @@ END;
 		}
 
 		$class = self::$supportedCommands[$commandCode][self::REQUESTHANDLER];
-		$handlerclass = REAL_BASE_PATH . "lib/request/" . strtolower($class) . ".php";
+		$handlerclass = REAL_BASE_PATH . "lib/request/" . strtolower((string) $class) . ".php";
 
 		if (is_file($handlerclass)) {
 			include $handlerclass;
