@@ -1,8 +1,9 @@
 <?php
+
 /*
  * SPDX-License-Identifier: AGPL-3.0-only
  * SPDX-FileCopyrightText: Copyright 2007-2016 Zarafa Deutschland GmbH
- * SPDX-FileCopyrightText: Copyright 2020-2024 grommunio GmbH
+ * SPDX-FileCopyrightText: Copyright 2020-2025 grommunio GmbH
  *
  * Detects an outgoing loop by looking if subsequent requests do try to get
  * changes for the same sync key. If more than once a synckey is requested,
@@ -105,7 +106,7 @@ class LoopDetection extends InterProcessData {
 			self::$processentry['stat'] = [];
 		}
 
-		self::$processentry['stat'][get_class($exception)] = $exception->getCode();
+		self::$processentry['stat'][$exception::class] = $exception->getCode();
 
 		$this->updateProcessStack();
 
@@ -121,7 +122,7 @@ class LoopDetection extends InterProcessData {
 	 * @return bool
 	 */
 	public function ProcessLoopDetectionAddStatus($folderid, $status) {
-		SLog::Write(LOGLEVEL_DEBUG, sprintf("LoopDetection->ProcessLoopDetectionAddStatus: '%s' with status %d", $folderid ? $folderid : 'hierarchy', $status));
+		SLog::Write(LOGLEVEL_DEBUG, sprintf("LoopDetection->ProcessLoopDetectionAddStatus: '%s' with status %d", $folderid ?: 'hierarchy', $status));
 		// generate entry if not already there
 		self::GetProcessEntry();
 
@@ -321,7 +322,7 @@ class LoopDetection extends InterProcessData {
 		$stack = $this->getProcessStack();
 		if (count($stack) > 1) {
 			$se = $stack[0];
-			if ($se['cc'] == GSync::COMMAND_SEARCH) {
+			if ($se['cc'] == GSync::COMMAND_SEARCH || $se['cc'] == GSync::COMMAND_FIND) {
 				return $se['pid'];
 			}
 		}
@@ -341,7 +342,7 @@ class LoopDetection extends InterProcessData {
 		$ok = false;
 		$tryCount = 1;
 		while (!$ok && $tryCount < 5) {
-			list($stack, $stackRaw) = $this->getDeviceUserData($this->type, parent::$devid, parent::$user, self::INTERPROCESSLD, true);
+			[$stack, $stackRaw] = $this->getDeviceUserData($this->type, parent::$devid, parent::$user, self::INTERPROCESSLD, true);
 
 			// insert/update current process entry
 			$nstack = [];
@@ -430,7 +431,7 @@ class LoopDetection extends InterProcessData {
 		$this->initializeParams();
 		$tryCount = 1;
 		while (!$ok && $tryCount < 5) {
-			list($brokenmsgs, $brokenmsgsRaw) = $this->getDeviceUserData($this->type, parent::$devid, parent::$user, $brokenkey, true);
+			[$brokenmsgs, $brokenmsgsRaw] = $this->getDeviceUserData($this->type, parent::$devid, parent::$user, $brokenkey, true);
 
 			$brokenmsgs[$id] = ['uuid' => $this->broken_message_uuid, 'counter' => $this->broken_message_counter];
 			SLog::Write(LOGLEVEL_DEBUG, sprintf("LoopDetection->SetBrokenMessage('%s', '%s'): tracking broken message", $folderid, $id));
@@ -474,7 +475,7 @@ class LoopDetection extends InterProcessData {
 		$ok = false;
 		$tryCount = 1;
 		while (!$ok && $tryCount < 5) {
-			list($brokenmsgs, $brokenmsgsRaw) = $this->getDeviceUserData($this->type, parent::$devid, parent::$user, $brokenkey, true);
+			[$brokenmsgs, $brokenmsgsRaw] = $this->getDeviceUserData($this->type, parent::$devid, parent::$user, $brokenkey, true);
 
 			if (empty($brokenmsgs)) {
 				break;
@@ -538,7 +539,7 @@ class LoopDetection extends InterProcessData {
 		$ok = false;
 		$tryCount = 1;
 		while (!$ok && $tryCount < 5) {
-			list($current, $currentRaw) = $this->getDeviceUserData($this->type, parent::$devid, parent::$user, $folderid, true);
+			[$current, $currentRaw] = $this->getDeviceUserData($this->type, parent::$devid, parent::$user, $folderid, true);
 
 			if (!isset($current["uuid"])) {
 				$current["uuid"] = $uuid;
@@ -667,7 +668,7 @@ class LoopDetection extends InterProcessData {
 		$ok = false;
 		$tryCount = 1;
 		while (!$ok && $tryCount < 5) {
-			list($current, $currentRaw) = $this->getDeviceUserData($this->type, parent::$devid, parent::$user, $folderid, true);
+			[$current, $currentRaw] = $this->getDeviceUserData($this->type, parent::$devid, parent::$user, $folderid, true);
 
 			// completely new/unknown UUID
 			if (empty($current)) {
@@ -782,7 +783,7 @@ class LoopDetection extends InterProcessData {
 				}
 			}
 			if (isset($current['loopcount'])) {
-				SLog::Write(LOGLEVEL_DEBUG, sprintf("LoopDetection->Detect(): loop data: loopcount(%d), maxCount(%d), queued(%d), ignored(%s)", $current['loopcount'], $current['maxCount'], $current['queued'], isset($current['ignored']) ? $current['ignored'] : 'false'));
+				SLog::Write(LOGLEVEL_DEBUG, sprintf("LoopDetection->Detect(): loop data: loopcount(%d), maxCount(%d), queued(%d), ignored(%s)", $current['loopcount'], $current['maxCount'], $current['queued'], $current['ignored'] ?? 'false'));
 			}
 
 			// update loop data
@@ -843,7 +844,7 @@ class LoopDetection extends InterProcessData {
 		$ok = false;
 		$tryCount = 1;
 		while (!$ok && $tryCount < 5) {
-			list($current, $currentRaw) = $this->getDeviceUserData($this->type, parent::$devid, parent::$user, $folderid, true);
+			[$current, $currentRaw] = $this->getDeviceUserData($this->type, parent::$devid, parent::$user, $folderid, true);
 
 			// we found our broken message!
 			if ($realBroken) {
@@ -853,11 +854,11 @@ class LoopDetection extends InterProcessData {
 
 				// check if this message was broken before - here we know that it still is and remove it from the tracking
 				$brokenkey = self::BROKENMSGS . "-" . $folderid;
-				// TODO: this is currently not supported here! It's in a different structure now!
-				//                if (isset($loopdata[self::$devid][self::$user][$brokenkey]) && isset($loopdata[self::$devid][self::$user][$brokenkey][$messageid])) {
-				//                    SLog::Write(LOGLEVEL_DEBUG, sprintf("LoopDetection->IgnoreNextMessage(): previously broken message '%s' is still broken and will not be tracked anymore", $messageid));
-				//                    unset($loopdata[self::$devid][self::$user][$brokenkey][$messageid]);
-				//                }
+			// TODO: this is currently not supported here! It's in a different structure now!
+			//                if (isset($loopdata[self::$devid][self::$user][$brokenkey]) && isset($loopdata[self::$devid][self::$user][$brokenkey][$messageid])) {
+			//                    SLog::Write(LOGLEVEL_DEBUG, sprintf("LoopDetection->IgnoreNextMessage(): previously broken message '%s' is still broken and will not be tracked anymore", $messageid));
+			//                    unset($loopdata[self::$devid][self::$user][$brokenkey][$messageid]);
+			//                }
 			}
 			// not the broken message yet
 			else {
