@@ -1,4 +1,5 @@
 <?php
+
 /*
  * SPDX-License-Identifier: AGPL-3.0-only
  * SPDX-FileCopyrightText: Copyright 2007-2016 Zarafa Deutschland GmbH
@@ -7,5 +8,4 @@
  * Indicates that a synchronization state could not be retrieved
  * from an IStateMachine.
  */
-class StateNotFoundException extends StatusException {
-}
+class StateNotFoundException extends StatusException {}
