@@ -1,4 +1,5 @@
 <?php
+
 /*
  * SPDX-License-Identifier: AGPL-3.0-only
  * SPDX-FileCopyrightText: Copyright 2007-2016 Zarafa Deutschland GmbH
@@ -6,5 +7,4 @@
  *
  * Indicates that a state was not yet loaded
  */
-class StateNotYetAvailableException extends StatusException {
-}
+class StateNotYetAvailableException extends StatusException {}
