@@ -1,4 +1,5 @@
 <?php
+
 /*
  * SPDX-License-Identifier: AGPL-3.0-only
  * SPDX-FileCopyrightText: Copyright 2007-2016 Zarafa Deutschland GmbH
@@ -18,7 +19,7 @@ class SyncObjectBrokenException extends GSyncException {
 	 * @return SyncObject
 	 */
 	public function GetSyncObject() {
-		return isset($this->syncObject) ? $this->syncObject : false;
+		return $this->syncObject ?? false;
 	}
 
 	/**
