@@ -1,4 +1,5 @@
 <?php
+
 /*
  * SPDX-License-Identifier: AGPL-3.0-only
  * SPDX-FileCopyrightText: Copyright 2016 Zarafa Deutschland GmbH
@@ -7,5 +8,4 @@
  * This is a fatal exception when e.g. a subsystem is not
  * available. The mobile should retry later.
  */
-class UnavailableException extends FatalException {
-}
+class UnavailableException extends FatalException {}
