@@ -1,4 +1,5 @@
 <?php
+
 /*
  * SPDX-License-Identifier: AGPL-3.0-only
  * SPDX-FileCopyrightText: Copyright 2007-2016 Zarafa Deutschland GmbH
@@ -25,7 +26,7 @@ class GetHierarchy extends RequestProcessor {
 
 			// TODO execute $data->Check() to see if SyncObject is valid
 		}
-		catch (StatusException $ex) {
+		catch (StatusException) {
 			return false;
 		}
 
