@@ -1,4 +1,5 @@
 <?php
+
 /*
  * SPDX-License-Identifier: AGPL-3.0-only
  * SPDX-FileCopyrightText: Copyright 2007-2016 Zarafa Deutschland GmbH
@@ -31,7 +32,7 @@ class Ping extends RequestProcessor {
 		try {
 			$sc->LoadAllCollections(true, true, true, true, false);
 		}
-		catch (StateInvalidException $siex) {
+		catch (StateInvalidException) {
 			// if no params are present, indicate to send params, else do hierarchy sync
 			if (!$params_present) {
 				$pingstatus = SYNC_PINGSTATUS_FAILINGPARAMS;
@@ -50,7 +51,7 @@ class Ping extends RequestProcessor {
 				self::$topCollector->AnnounceInformation("StateInvalidException: force sync", true);
 			}
 		}
-		catch (StatusException $stex) {
+		catch (StatusException) {
 			$pingstatus = SYNC_PINGSTATUS_FOLDERHIERSYNCREQUIRED;
 			self::$topCollector->AnnounceInformation("StatusException: require HierarchySync", true);
 		}
@@ -104,7 +105,7 @@ class Ping extends RequestProcessor {
 								continue;
 							}
 						}
-						catch (NoHierarchyCacheAvailableException $nhca) {
+						catch (NoHierarchyCacheAvailableException) {
 							SLog::Write(LOGLEVEL_INFO, sprintf("HandlePing(): unknown collection '%s', triggering HierarchySync", $folderid));
 							$pingstatus = SYNC_PINGSTATUS_FOLDERHIERSYNCREQUIRED;
 						}
