@@ -1,4 +1,5 @@
 <?php
+
 /*
  * SPDX-License-Identifier: AGPL-3.0-only
  * SPDX-FileCopyrightText: Copyright 2007-2016 Zarafa Deutschland GmbH
@@ -9,7 +10,6 @@
 
 class WBXMLEncoder extends WBXMLDefs {
 	private $_dtd;
-	private $_out;
 	private $_tagcp = 0;
 	private $log = false;
 	private $logStack = [];
@@ -20,13 +20,11 @@ class WBXMLEncoder extends WBXMLDefs {
 
 	// Only when content() is called do we output the current stack of tags
 
-	private $_stack;
-	private $multipart; // the content is multipart
+	private $_stack; // the content is multipart
 	private $bodyparts;
 
-	public function __construct($output, $multipart = false) {
+	public function __construct(private $_out, private $multipart = false) {
 		$this->log = SLog::IsWbxmlDebugEnabled();
-		$this->_out = $output;
 
 		// reverse-map the DTD
 		foreach ($this->dtd["namespaces"] as $nsid => $nsname) {
@@ -40,7 +38,6 @@ class WBXMLEncoder extends WBXMLDefs {
 			}
 		}
 		$this->_stack = [];
-		$this->multipart = $multipart;
 		$this->bodyparts = [];
 	}
 
@@ -65,6 +62,10 @@ class WBXMLEncoder extends WBXMLDefs {
 
 	/**
 	 * Puts a StartTag on the output stack.
+	 *
+	 * @param mixed $tag
+	 * @param mixed $attributes
+	 * @param mixed $nocontent
 	 */
 	public function startTag($tag, $attributes = false, $nocontent = false) {
 		$stackelem = [];
@@ -76,8 +77,8 @@ class WBXMLEncoder extends WBXMLDefs {
 
 			array_push($this->_stack, $stackelem);
 
-			// If 'nocontent' is specified, then apparently the user wants to force
-			// output of an empty tag, and we therefore output the stack here
+		// If 'nocontent' is specified, then apparently the user wants to force
+		// output of an empty tag, and we therefore output the stack here
 		}
 		else {
 			$this->_outputStack();
@@ -287,6 +288,8 @@ class WBXMLEncoder extends WBXMLDefs {
 
 	/**
 	 * Outputs a byte.
+	 *
+	 * @param mixed $byte
 	 */
 	private function outByte($byte) {
 		fwrite($this->_out, chr($byte));
@@ -327,14 +330,18 @@ class WBXMLEncoder extends WBXMLDefs {
 
 	/**
 	 * Outputs content with string terminator.
+	 *
+	 * @param mixed $content
 	 */
 	private function outTermStr($content) {
-		fwrite($this->_out, $content);
+		fwrite($this->_out, (string) $content);
 		fwrite($this->_out, chr(0));
 	}
 
 	/**
 	 * Switches the codepage.
+	 *
+	 * @param mixed $page
 	 */
 	private function outSwitchPage($page) {
 		$this->outByte(self::WBXML_SWITCH_PAGE);
@@ -344,6 +351,8 @@ class WBXMLEncoder extends WBXMLDefs {
 	/**
 	 * Get the mapping for a tag.
 	 *
+	 * @param mixed $tag
+	 *
 	 * @return array
 	 */
 	private function getMapping($tag) {
@@ -369,15 +378,17 @@ class WBXMLEncoder extends WBXMLDefs {
 	/**
 	 * Split a tag from a the fulltag (namespace + tag).
 	 *
+	 * @param mixed $fulltag
+	 *
 	 * @return array keys: 'ns' (namespace), 'tag' (tag)
 	 */
 	private function splitTag($fulltag) {
 		$ns = false;
-		$pos = strpos($fulltag, chr(58)); // chr(58) == ':'
+		$pos = strpos((string) $fulltag, chr(58)); // chr(58) == ':'
 
 		if ($pos) {
-			$ns = substr($fulltag, 0, $pos);
-			$tag = substr($fulltag, $pos + 1);
+			$ns = substr((string) $fulltag, 0, $pos);
+			$tag = substr((string) $fulltag, $pos + 1);
 		}
 		else {
 			$tag = $fulltag;
@@ -394,6 +405,9 @@ class WBXMLEncoder extends WBXMLDefs {
 
 	/**
 	 * Logs a StartTag to SLog.
+	 *
+	 * @param mixed $tag
+	 * @param mixed $nocontent
 	 */
 	private function logStartTag($tag, $nocontent) {
 		$spaces = str_repeat(" ", count($this->logStack));
@@ -440,7 +454,7 @@ class WBXMLEncoder extends WBXMLDefs {
 		foreach ($this->bodyparts as $i => $bp) {
 			$blockstart = $blockstart + $len;
 			$len = fstat($bp);
-			$len = (isset($len['size'])) ? $len['size'] : 0;
+			$len = $len['size'] ?? 0;
 			if ($len == 0) {
 				SLog::Write(LOGLEVEL_WARN, sprintf("WBXMLEncoder->processMultipart(): the length of the body part at position %d is 0", $i));
 			}
